SELECT 1/mysqlclient - Criterion.rs

## SELECT 1/mysqlclient

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0044198 | 0.0045883 | 0.0044155
Mean | 7.9002 ms | 8.0397 ms | 8.1810 ms
Std. Dev. | 629.73 µs | 716.35 µs | 794.51 µs
Median | 7.8185 ms | 8.1912 ms | 8.2784 ms
MAD | 570.89 µs | 789.72 µs | 991.01 µs

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.